summaryrefslogtreecommitdiffstats
path: root/core/java/android/text/format
diff options
context:
space:
mode:
authorElliott Hughes <enh@google.com>2013-03-18 14:59:59 -0700
committerElliott Hughes <enh@google.com>2013-03-18 14:59:59 -0700
commitfc55c2ba49957bb696b98d290964dc36f4827190 (patch)
tree6df660c360f95b6075ffc8633356d67ae04d4839 /core/java/android/text/format
parentfda1bff8a8eda96662577820102aaaa02a0845b6 (diff)
downloadframeworks_base-fc55c2ba49957bb696b98d290964dc36f4827190.zip
frameworks_base-fc55c2ba49957bb696b98d290964dc36f4827190.tar.gz
frameworks_base-fc55c2ba49957bb696b98d290964dc36f4827190.tar.bz2
Deliberately break DateFormat.format's formatting of 'k' for compatibility.
Bug: 8359981 Change-Id: I44ed816c644f94783c77952d544c5444b966868b
Diffstat (limited to 'core/java/android/text/format')
-rw-r--r--core/java/android/text/format/DateFormat.java27
1 files changed, 20 insertions, 7 deletions
diff --git a/core/java/android/text/format/DateFormat.java b/core/java/android/text/format/DateFormat.java
index ef2c248..c4e960a 100644
--- a/core/java/android/text/format/DateFormat.java
+++ b/core/java/android/text/format/DateFormat.java
@@ -43,11 +43,17 @@ import libcore.icu.LocaleData;
* for both formatting and parsing dates. For the canonical documentation
* of format strings, see {@link java.text.SimpleDateFormat}.
*
- * <p>The format methods in this class implement a subset of Unicode
+ * <p>The {@code format} methods in this class implement a subset of Unicode
* <a href="http://www.unicode.org/reports/tr35/#Date_Format_Patterns">UTS #35</a> patterns.
* The subset supported by this class includes the following format characters:
* {@code acdEHhLKkLMmsyz}. See {@link java.text.SimpleDateFormat} for more documentation
* about patterns, or if you need a more compete implementation.
*/
public class DateFormat {
/** @deprecated Use a literal {@code '} instead. */
@@ -74,7 +80,11 @@ public class DateFormat {
@Deprecated
public static final char HOUR = 'h';
- /** @deprecated Use a literal {@code 'k'} instead. */
+ /**
+ * @deprecated Use a literal {@code 'H'} (for compatibility with {@link SimpleDateFormat}
+ * and Unicode) or {@code 'k'} (for compatibility with Android releases up to and including
+ * Jelly Bean MR-1) instead. Note that the two are incompatible.
+ */
@Deprecated
public static final char HOUR_OF_DAY = 'k';
@@ -441,10 +451,13 @@ public class DateFormat {
}
break;
case 'H': // hour in day (0-23)
- case 'k': // hour in day (1-24)
+ case 'k': // hour in day (1-24) [but see note below]
{
int hour = inDate.get(Calendar.HOUR_OF_DAY);
- if (c == 'k' && hour == 0) {
+ // Historically on Android 'k' was interpreted as 'H', which wasn't
+ // implemented, so pretty much all callers that want to format 24-hour
+ // times are abusing 'k'. http://b/8359981.
+ if (false && c == 'k' && hour == 0) {
hour = 24;
}
replacement = zeroPad(hour, count);
@@ -43,11 +43,17 @@ import libcore.icu.LocaleData;
* <a href="http://www.unicode.org/reports/tr35/#Date_Format_Patterns">UTS #35</a> patterns.
- * The subset supported by this class includes the following format characters:
- * {@code acdEHhLKkLMmsyz}. See {@link java.text.SimpleDateFormat} for more documentation
- * about patterns, or if you need a more compete implementation.
+ * The subset currently supported by this class includes the following format characters:
+ * {@code acdEHhLKkLMmsyz}. Up to API level 17, only {@code adEhkMmszy} were supported.
+ * Note that this class incorrectly implements {@code k} as if it were {@code H} for backwards
+ * compatibility.
+ *
+ * <p>See {@link java.text.SimpleDateFormat} for more documentation
+ * about patterns, or if you need a more complete or correct implementation.
+ * Note that the non-{@code format} methods in this class are implemented by
+ * {@code SimpleDateFormat}.
*/
public class DateFormat {